==> falorem-0.0.2.tgz: package/README.md <==
<h1 dir="rtl">falorem</h1>

<p dir="rtl">
falorem یک ماژول جاواسکریپت برای تولید متن لورم ایپسوم به زبان فارسی است
لورم ایپسوم متنی آزمایشی و بی معنی در طراحی می باشد که طراح گرافیک از این متن به عنوان عنصری از ترکیب بندی برای پر کردن صفحه و ارایه اولیه شکل ظاهری و کلی طرح سفارش گرفته شده استفاده می نماید
</p>

<h2 dir="rtl">
نصب
</h2>

`npm install falorem --save-dev`

یا

`yarn add faloerm --dev`

<h2 dir="rtl">
روش استفاده
</h2>

```javascript
const lorem = require('falorem');


lorem.words(5);
// 'لورم ایپسوم یک متن ساختگی'

lorem.sentences(5);
// 'لورم ایپسوم متن ساختگی با تولید سادگی نامفهوم از صنعت چاپ و با استفاده از طراحان گرافیک است.'

lorem.paragraphs(1);
// 'لورم ایپسوم متن ساختگی با تولید سادگی نامفهوم از صنعت چاپ و با استفاده از طراحان گرافیک است. چاپگرها و متون بلکه روزنامه و مجله در ستون و سطرآنچنان که لازم است و برای شرایط فعلی تکنولوژی مورد نیاز و کاربردهای متنوع با هدف بهبود ابزارهای کاربردی می باشد. کتابهای زیادی در شصت و سه درصد گذشته، حال و آینده شناخت فراوان جامعه و متخصصان را می طلبد تا با نرم افزارها شناخت بیشتری را برای طراحان رایانه ای علی الخصوص طراحان خلاقی و فرهنگ پیشرو در زبان فارسی ایجاد کرد. در این صورت می توان امید داشت که تمام و دشواری موجود در ارائه راهکارها و شرایط سخت تایپ به پایان رسد و زمان مورد نیاز شامل حروفچینی دستاوردهای اصلی و جوابگوی سوالات پیوسته اهل دنیای موجود طراحی اساسا مورد استفاده قرار گیرد'

```

## Contributing

<p dir="rtl">به صورت کلی ما از روش fork-and-pull استفاده میکنیم</p>

<ol dir="rtl">
  <li>repository را fork کنید</li>
  <li>روی ماشین خود clone کنید</li>
  <li>پس از اعمال تغییرات کد رو تست کنید (در صورت نیاز تست اضافه کنید)</li>
  <li>تغییرتا خود را commit کنید</li>
  <li>تغییرات خود را push کنید</li>
  <li>یک pull request ثبت کنید.</li>
</ol>

<h2 dir="rtl">لایسنس</h2>

<p dir="rtl">
falorem تحت لایسنس MIT هست.
</p>

==> falorem-1.0.4.tgz: package/README.md <==
<h1 dir="rtl">falorem</h1>

<p dir="rtl">
falorem یک ماژول جاواسکریپت برای تولید متن لورم ایپسوم به زبان فارسی است
لورم ایپسوم متنی آزمایشی و بی معنی در طراحی می باشد که طراح گرافیک از این متن به عنوان عنصری از ترکیب بندی برای پر کردن صفحه و ارایه اولیه شکل ظاهری و کلی طرح سفارش گرفته شده استفاده می نماید
</p>

<h2 dir="rtl">
نصب
</h2>

`npm install falorem --save-dev`

<h2 dir="rtl">
روش استفاده
</h2>

```javascript
const lorem = require('falorem');


lorem.words(5);
// 'لورم ایپسوم یک متن ساختگی'

lorem.sentences(5);
// 'لورم ایپسوم متن ساختگی با تولید سادگی نامفهوم از صنعت چاپ و با استفاده از طراحان گرافیک است.'

lorem.paragraphs(1);
// 'لورم ایپسوم متن ساختگی با تولید سادگی نامفهوم از صنعت چاپ و با استفاده از طراحان گرافیک است. چاپگرها و متون بلکه روزنامه و مجله در ستون و سطرآنچنان که لازم است و برای شرایط فعلی تکنولوژی مورد نیاز و کاربردهای متنوع با هدف بهبود ابزارهای کاربردی می باشد. کتابهای زیادی در شصت و سه درصد گذشته، حال و آینده شناخت فراوان جامعه و متخصصان را می طلبد تا با نرم افزارها شناخت بیشتری را برای طراحان رایانه ای علی الخصوص طراحان خلاقی و فرهنگ پیشرو در زبان فارسی ایجاد کرد. در این صورت می توان امید داشت که تمام و دشواری موجود در ارائه راهکارها و شرایط سخت تایپ به پایان رسد و زمان مورد نیاز شامل حروفچینی دستاوردهای اصلی و جوابگوی سوالات پیوسته اهل دنیای موجود طراحی اساسا مورد استفاده قرار گیرد'
```

<h2 dir="rtl">
استفاده در مرورگر
<h2>

```html
<script src="https://unpkg.com/falorem[@<VERSION>]/falorem.min.js"></script>
<script>
  Falorem.words(5)
  // 'لورم ایپسوم یک متن ساختگی'
</script>
```

<h2 dir="rtl">مشارکت در توسعه</h2>

<p dir="rtl">به صورت کلی ما از روش fork-and-pull استفاده میکنیم</p>

<ol dir="rtl">
  <li>repository را fork کنید</li>
  <li>روی ماشین خود clone کنید</li>
  <li>پس از اعمال تغییرات کد رو تست کنید (در صورت نیاز تست اضافه کنید)</li>
  <li>تغییرات خود را commit کنید</li>
  <li>تغییرات خود را push کنید</li>
  <li>یک pull request ثبت کنید.</li>
</ol>

<h2 dir="rtl">لایسنس</h2>

<p dir="rtl">
falorem تحت لایسنس MIT هست.
</p>
